@@ -7,9 +7,10 @@ use Devel::StackTrace;
 use IO::File;
 use UNIVERSAL::require;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our $A_HEAD = '<a class="package" href="?rm=view_code&amp;module=';
+our $A_HEAD_POD = '<a class="package" href="?rm=view_pod&amp;module=';
 our $A_TAIL = ';view_code_no_popup=1">';
 our $A_END  = '</a>';
 
@@ -46,6 +47,10 @@ our $TEMPLATE = qq{
                -moz-border-radius: 10px;
                overflow: auto;
            }
+           div.infos td.head{
+               text-align: center;
+           }
+
            h1 {
                margin: 0;
                color: #999999;
@@ -97,16 +102,22 @@ our $TEMPLATE = qq{
                        <th>Package</th>
                        <th>Line   </th>
                        <th>File   </th>
+                       <!-- TMPL_IF NAME="view" -->
+                       <th>View   </th>
+                       <!-- /TMPL_IF -->
                    </tr>
                    <!-- TMPL_LOOP NAME="stacktrace" -->
                        <tr>
-                           <td><!-- TMPL_VAR NAME="package" --></td>
+                           <td class="head"><!-- TMPL_VAR NAME="package" --></td>
 
-                           <td><!-- TMPL_VAR NAME="line" --></td>
-                           <td><!-- TMPL_VAR NAME="filename" --></td>
+                           <td class="head"><!-- TMPL_VAR NAME="line" --></td>
+                           <td class="head"><!-- TMPL_VAR NAME="filename" --></td>
+                           <!-- TMPL_IF NAME="view" -->
+                           <td class="head"><!-- TMPL_VAR NAME="code" --> <!-- TMPL_VAR NAME="pod" --></td>
+                           <!-- /TMPL_IF -->
                        </tr>
                        <tr>
-                           <td colspan="3"><pre><!-- TMPL_VAR NAME="code_preview" --></pre></td>
+                           <td colspan="4"><pre><!-- TMPL_VAR NAME="code_preview" --></pre></td>
                        </tr>
                    <!-- /TMPL_LOOP -->
                </table>
@@ -178,12 +189,17 @@ sub debug_report{
         $s{filename} = exists $stack->{file} ? $stack->{file} : $stack->{filename};
 
         $s{package}  = html_escape($s{package});
-        if ( $self->{__viewcode} && $s{package} ne 'main' ) {
-            $s{package} = $A_HEAD . $s{package} . $A_TAIL . $s{package} . $A_END;
-        }
         $s{filename} = html_escape($s{filename});
         $s{line}     = html_escape($stack->{line});
         $s{code_preview} = print_context($s{filename},$s{line});
+
+        if ( $self->{__viewcode} && $s{package} ne 'main' ) {
+            $s{code} = $A_HEAD . $s{package} . $A_TAIL . "code" . $A_END;
+            $s{pod}  = $A_HEAD_POD . $s{package} . $A_TAIL . "pod" . $A_END;
+            $s{filename} = $A_HEAD . $s{package} . $A_TAIL . $s{filename} . $A_END;
+            $s{package} = $A_HEAD . $s{package} . $A_TAIL . $s{package} . $A_END;
+            $s{view} = $self->{__viewcode};
+        }
         push @stacktraces, \%s;
     }
 
@@ -194,6 +210,7 @@ sub debug_report{
     $t->param(
         title   => $title,
         title_a => $title_a,
+        view    => $self->{__viewcode},
         url     => html_escape($url),
         desc    => html_escape($desc),
         stacktrace => \@stacktraces,
@@ -245,29 +262,33 @@ CGI::Application::Plugin::DebugScreen - add Debug support to CGI::Application.
 
 =head1 VERSION
 
-This documentation refers to CGI::Application::Plugin::DebugScreen version 0.04
+This documentation refers to CGI::Application::Plugin::DebugScreen version 0.05
 
 =head1 SYNOPSIS
 
   use CGI::Application::Plugin::DebugScreen;
 
 Only it.
-If 500 http's error is generated...
+If "Internal Server Error" was generated by "run_mode"....
 
 =head1 DESCRIPTION
 
 This plug-in add Debug support to CGI::Application.
 This plug-in like Catalyst debug mode.
 
-When 'die' is generated by 'runmode',
+When 'die' is generated by 'run_mode',
  this plug-in outputs the stack trace by error_mode().
-The error cannot be caught excluding runmode.
+The error cannot be caught excluding run_mode.
 
 This uses CGI::Application::Plugin::ViewCode
  if a state that CGI::Application::Plugin::ViewCode can be used or used. 
 But CGI::Application::Dispatch is used,
  this not uses CGI::Application::Plugin::ViewCode.
 
+When CGI::Application::Plugin::ViewCode can be used,
+ Title, Package, File, and code are links to CGI::Application::Plugin::ViewCode's view_code mode.
+And pod are links to CGI::Application::Plugin::ViewCode's view_pod mode.
+
 =head1 DEPENDENCIES
 
 L<strict>
